==> istio-model-v1alpha3-6.6.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterSpecFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface EnvoyFilterSpecFluent<A extends EnvoyFilterSpecFluent<A>> extends Fluent<A>{
  public A addToConfigPatches(Integer index,EnvoyFilterEnvoyConfigObjectPatch item);
  public A setToConfigPatches(Integer index,EnvoyFilterEnvoyConfigObjectPatch item);
  public A addToConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... items);
  public A addAllToConfigPatches(Collection<EnvoyFilterEnvoyConfigObjectPatch> items);
  public A removeFromConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... items);
  public A removeAllFromConfigPatches(Collection<EnvoyFilterEnvoyConfigObjectPatch> items);
  public A removeMatchingFromConfigPatches(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConfigPatches instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<EnvoyFilterEnvoyConfigObjectPatch> getConfigPatches();
  public List<EnvoyFilterEnvoyConfigObjectPatch> buildConfigPatches();
  public EnvoyFilterEnvoyConfigObjectPatch buildConfigPatch(Integer index);
  public EnvoyFilterEnvoyConfigObjectPatch buildFirstConfigPatch();
  public EnvoyFilterEnvoyConfigObjectPatch buildLastConfigPatch();
  public EnvoyFilterEnvoyConfigObjectPatch buildMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate);
  public Boolean hasMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate);
  public A withConfigPatches(List<EnvoyFilterEnvoyConfigObjectPatch> configPatches);
  public A withConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... configPatches);
  public Boolean hasConfigPatches();
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> addNewConfigPatch();
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> addNewConfigPatchLike(EnvoyFilterEnvoyConfigObjectPatch item);
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> setNewConfigPatchLike(Integer index,EnvoyFilterEnvoyConfigObjectPatch item);
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> editConfigPatch(Integer index);
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> editFirstConfigPatch();
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> editLastConfigPatch();
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> editMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate);
  public Integer getPriority();
  public A withPriority(Integer priority);
  public Boolean hasPriority();
  
  /**
   * This method has been deprecated, please use method buildWorkloadSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadSelector getWorkloadSelector();
  public WorkloadSelector buildWorkloadSelector();
  public A withWorkloadSelector(WorkloadSelector workloadSelector);
  public Boolean hasWorkloadSelector();
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> withNewWorkloadSelector();
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> withNewWorkloadSelectorLike(WorkloadSelector item);
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> editWorkloadSelector();
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> editOrNewWorkloadSelector();
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> editOrNewWorkloadSelectorLike(WorkloadSelector item);
  public interface ConfigPatchesNested<N> extends Nested<N>,EnvoyFilterEnvoyConfigObjectPatchFluent<EnvoyFilterSpecFluent.ConfigPatchesNested<N>>{
    public N and();
    public N endConfigPatch();
    
  }
  public interface WorkloadSelectorNested<N> extends Nested<N>,WorkloadSelectorFluent<EnvoyFilterSpecFluent.WorkloadSelectorNested<N>>{
    public N and();
    public N endWorkloadSelector();
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterSpecFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface EnvoyFilterSpecFluent<A extends EnvoyFilterSpecFluent<A>> extends Fluent<A>{
  public A addToConfigPatches(int index,EnvoyFilterEnvoyConfigObjectPatch item);
  public A setToConfigPatches(int index,EnvoyFilterEnvoyConfigObjectPatch item);
  public A addToConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... items);
  public A addAllToConfigPatches(Collection<EnvoyFilterEnvoyConfigObjectPatch> items);
  public A removeFromConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... items);
  public A removeAllFromConfigPatches(Collection<EnvoyFilterEnvoyConfigObjectPatch> items);
  public A removeMatchingFromConfigPatches(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConfigPatches instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<EnvoyFilterEnvoyConfigObjectPatch> getConfigPatches();
  public List<EnvoyFilterEnvoyConfigObjectPatch> buildConfigPatches();
  public EnvoyFilterEnvoyConfigObjectPatch buildConfigPatch(int index);
  public EnvoyFilterEnvoyConfigObjectPatch buildFirstConfigPatch();
  public EnvoyFilterEnvoyConfigObjectPatch buildLastConfigPatch();
  public EnvoyFilterEnvoyConfigObjectPatch buildMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate);
  public Boolean hasMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate);
  public A withConfigPatches(List<EnvoyFilterEnvoyConfigObjectPatch> configPatches);
  public A withConfigPatches(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterEnvoyConfigObjectPatch... configPatches);
  public Boolean hasConfigPatches();
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> addNewConfigPatch();
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> addNewConfigPatchLike(EnvoyFilterEnvoyConfigObjectPatch item);
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> setNewConfigPatchLike(int index,EnvoyFilterEnvoyConfigObjectPatch item);
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> editConfigPatch(int index);
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> editFirstConfigPatch();
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> editLastConfigPatch();
  public EnvoyFilterSpecFluent.ConfigPatchesNested<A> editMatchingConfigPatch(Predicate<EnvoyFilterEnvoyConfigObjectPatchBuilder> predicate);
  public Integer getPriority();
  public A withPriority(Integer priority);
  public Boolean hasPriority();
  
  /**
   * This method has been deprecated, please use method buildWorkloadSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadSelector getWorkloadSelector();
  public WorkloadSelector buildWorkloadSelector();
  public A withWorkloadSelector(WorkloadSelector workloadSelector);
  public Boolean hasWorkloadSelector();
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> withNewWorkloadSelector();
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> withNewWorkloadSelectorLike(WorkloadSelector item);
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> editWorkloadSelector();
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> editOrNewWorkloadSelector();
  public EnvoyFilterSpecFluent.WorkloadSelectorNested<A> editOrNewWorkloadSelectorLike(WorkloadSelector item);
  public interface ConfigPatchesNested<N> extends Nested<N>,EnvoyFilterEnvoyConfigObjectPatchFluent<EnvoyFilterSpecFluent.ConfigPatchesNested<N>>{
    public N and();
    public N endConfigPatch();
    
  }
  public interface WorkloadSelectorNested<N> extends Nested<N>,WorkloadSelectorFluent<EnvoyFilterSpecFluent.WorkloadSelectorNested<N>>{
    public N and();
    public N endWorkloadSelector();
    
  }
  
}
